==> purchaser-invoice-saas-client-0.0.55-sources.jar: com/xforceplus/purchaserinvoicesaas/controller/InvoiceMainFeignApi.java <==
package com.xforceplus.purchaserinvoicesaas.controller;


/**
 * 发票票面信息feign客户端
 *
 * @author ultraman
 * @date 2022-07-04
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.purchaserinvoicesaas.entity.InvoiceMain;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "purchaser-invoice-saas")
public interface InvoiceMainFeignApi {

  /**
   * 通过id查询发票票面信息
   * @param  id
   * @return R
   */
  @GetMapping("/invoiceMain/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增发票票面信息
   * @param invoiceMain 发票票面信息
   * @return R
   */
  @PostMapping("/invoiceMain/add")
  public R save(@RequestBody InvoiceMain invoiceMain);

  /**
   * 修改发票票面信息
   * @param invoiceMain 发票票面信息
   * @return R
   */
  @PostMapping("/invoiceMain/update")
  public R updateById(@RequestBody InvoiceMain invoiceMain);

  /**
   * 通过id删除发票票面信息
   * @param  id
   * @return R
   */
  @DeleteMapping("/invoiceMain/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> purchaser-invoice-saas-client-0.0.167-sources.jar: com/xforceplus/purchaserinvoicesaas/controller/InvoiceMainFeignApi.java <==
package com.xforceplus.purchaserinvoicesaas.controller;


/**
 * 发票票面信息feign客户端
 *
 * @author ultraman
 * @date 2023-01-09
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.purchaserinvoicesaas.entity.InvoiceMain;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "purchaser-invoice-saas")
public interface InvoiceMainFeignApi {

  /**
   * 通过id查询发票票面信息
   * @param  id
   * @return R
   */
  @GetMapping("/invoiceMain/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增发票票面信息
   * @param invoiceMain 发票票面信息
   * @return R
   */
  @PostMapping("/invoiceMain/add")
  public R save(@RequestBody InvoiceMain invoiceMain);

  /**
   * 修改发票票面信息
   * @param invoiceMain 发票票面信息
   * @return R
   */
  @PostMapping("/invoiceMain/update")
  public R updateById(@RequestBody InvoiceMain invoiceMain);

  /**
   * 通过id删除发票票面信息
   * @param  id
   * @return R
   */
  @DeleteMapping("/invoiceMain/del/{id}" )
  public R removeById(@PathVariable Long id);

}
